# DashboardResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**projects** | [**list[DashboardProjectResource]**](DashboardProjectResource.md) |  | [optional] 
**project_groups** | [**list[DashboardProjectGroupResource]**](DashboardProjectGroupResource.md) |  | [optional] 
**environments** | [**list[DashboardEnvironmentResource]**](DashboardEnvironmentResource.md) |  | [optional] 
**tenants** | [**list[DashboardTenantResource]**](DashboardTenantResource.md) |  | [optional] 
**items** | [**list[DashboardItemResource]**](DashboardItemResource.md) |  | [optional] 
**previous_items** | [**list[DashboardItemResource]**](DashboardItemResource.md) |  | [optional] 
**project_limit** | **int** |  | [optional] 
**is_filtered** | **bool** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


